/* ****************************************** */
/* CGM.DO                                     */
/*                                            */
/* Apply Cameron-Gelbach-Miller multiway      */
/*   cluster method to state-year-age regs    */
/*                                            */
/* ****************************************** */

#delimit ;

clear;
drop _all;
set more 1; 
set memory 1g;
set matsize 8000;
set maxvar 10000;

use ../../../data/adata;
keep if year >= 1985 & year <= 1998;
summ;

gen l_prop_pc_s = ln(proparr/seerpop);
gen l_viol_pc_s = ln(violarr/seerpop);

gen fipsyear = fips*10000 + year;
  quietly tab fipsyear, gen(fy);

gen  ageyear =  age*10000 + year;
  quietly tab ageyear, gen(ay);

gen fipsage  = fips*10000 + age;
  quietly tab fipsage, gen(fa);

* Run standard models as a check;

xi: reg  l_prop_pc_s hist_abt i.fips*i.year i.fips*i.age i.age*i.year [aw=popul], cluster(fips);
xi: reg  l_viol_pc_s hist_abt i.fips*i.year i.fips*i.age i.age*i.year [aw=popul], cluster(fips);

* Now whiten the crime and abortion rates. Note that we have to whiten the 
* abortion rates twice to reflect the differing availability of L_PROP_PC_S and 
* L_VIOL_PC_S ;
                                                                
qui xi: reg  l_prop_pc_s i.fips*i.year i.fips*i.age i.age*i.year [aw=popul];
  predict double propresid, resid;

qui xi: reg  l_viol_pc_s i.fips*i.year i.fips*i.age i.age*i.year [aw=popul];
  predict double violresid, resid;

qui xi: reg  hist_abt    i.fips*i.year i.fips*i.age i.age*i.year if l_prop_pc_s ~= . [aw=popul];
  predict double abresid_prop, resid;

qui xi: reg  hist_abt    i.fips*i.year i.fips*i.age i.age*i.year if l_viol_pc_s ~= . [aw=popul];
  predict double abresid_viol, resid;

keep fips year age propresid violresid abresid_* popul fipsyear ageyear fipsage yobstate;

scalar nobs_prop = 6730;
scalar nobs_viol = 6724;

save cgm, replace;

use cgm, clear;

/* It is surprisingly hard to count regressors */ 
/* in STATA, so we set the correct number of   */
/* regressors for the state-yr-age regressions  */
/* here.                                       */
/* See how we counted them in the NREG_COUNTS  */
/* subdirectory                                */

scalar good_k = 1250;
 disp good_k;

/* *************************************************** */
/* *************************************************** */
/* Property Crime ************************************ */ 

scalar dfadj = sqrt( (nobs_prop - 1) / (nobs_prop - good_k) );
 disp dfadj;

* Use REG as a check;
reg    propresid abresid_prop [aw=popul], noconst cluster(fips);
  disp _se[abresid_prop];
  disp (_b[abresid_prop]/(_se[abresid_prop]));
  disp 2*(1-normal(abs(_b[abresid_prop]/(_se[abresid_prop]))));

  disp _se[abresid_prop]*dfadj;
  disp (_b[abresid_prop]/(_se[abresid_prop]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_prop]/(_se[abresid_prop]*dfadj))));

* Run a CGM model as a check ;
cgmreg  propresid abresid_prop [aw=popul], nocons cluster(fips);
  disp _se[abresid_prop]*dfadj;
  disp (_b[abresid_prop]/(_se[abresid_prop]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_prop]/(_se[abresid_prop]*dfadj))));

* Now use CGM to cluster several ways at the same time;
cgmreg  propresid abresid_prop [aw=popul], nocons cluster(yobstate fipsyear fipsage);
  disp _se[abresid_prop]*dfadj;
  disp (_b[abresid_prop]/(_se[abresid_prop]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_prop]/(_se[abresid_prop]*dfadj))));

/* *************************************************** */
/* *************************************************** */
/* Violent Crime  ************************************ */ 

scalar drop dfadj;
scalar dfadj = sqrt( (nobs_viol - 1) / (nobs_viol - good_k) );
 disp dfadj;

* Use REG as a check;
reg    violresid abresid_viol [aw=popul], nocons cluster(fips);
  disp _se[abresid_viol];
  disp (_b[abresid_viol]/(_se[abresid_viol]));
  disp 2*(1-normal(abs(_b[abresid_viol]/(_se[abresid_viol]))));

  disp _se[abresid_viol]*dfadj;
  disp (_b[abresid_viol]/(_se[abresid_viol]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_viol]/(_se[abresid_viol]*dfadj))));

* Run a CGM model as a check ;
cgmreg  violresid abresid_viol [aw=popul], nocons cluster(fips);
  disp _se[abresid_viol]*dfadj;
  disp (_b[abresid_viol]/(_se[abresid_viol]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_viol]/(_se[abresid_viol]*dfadj))));

* Now use CGM to cluster several ways at the same time;
cgmreg  violresid abresid_viol [aw=popul], nocons cluster(yobstate fipsyear fipsage);
  disp _se[abresid_viol]*dfadj;
  disp (_b[abresid_viol]/(_se[abresid_viol]*dfadj));
  disp 2*(1-normal(abs(_b[abresid_viol]/(_se[abresid_viol]*dfadj))));


exit, clear;
