/* ****************************************** */
/* STYRAGE2.DO                                */
/*                                            */
/* Does Prais-Winsten models with back-of-    */
/* the envelope bias correction informed      */
/* by Solon (1984)                            */
/*                                            */
/* You must use STATA-SE to run this program  */
/* Stata-MP may get the Prais models wrong b/c*/
/* of their sequential nature                 */
/*                                            */
/* ****************************************** */

drop _all 
set more 1 
set memory 1g
set matsize 8000 
set maxvar 10000

#delimit ;
use ../../../data/adata;
keep if year >= 1985 & year <= 1998;
summ;

gen l_prop_pc_s = ln(proparr/seerpop);
gen l_viol_pc_s = ln(violarr/seerpop);

egen censwt = mean(censuspop), by(fips);

gen fipsyear = fips*10000 + year;
  quietly tab fipsyear, gen(fy);

gen  ageyear =  age*10000 + year;
  quietly tab ageyear, gen(ay);

gen fipsage  = fips*10000 + age;
  quietly tab fipsage, gen(fa);

sort fipsage year;
tsset fipsage year;

/* *************************************************** */
/* *************************************************** */
/* Property Crime ************************************ */ 
                   
* SYA regression with varying population weights POPUL (as in TABLE I);                                                   
xi: reg  l_prop_pc_s hist_abt   i.fips*i.year i.fips*i.age i.age*i.year [aw=popul]  , cluster(fips);

* SYA regression with constant population weights CENSWT (needed for PRAIS);
xi: reg  l_prop_pc_s hist_abt   i.fips*i.year i.fips*i.age i.age*i.year [aw=censwt] , cluster(fips);
xi: reg  l_prop_pc_s hist_abt     fy*           fa*          ay*        [aw=censwt] , cluster(fips);

* PRAIS regression as STATA does it, no adjustment on RHOHAT;
xi: prais  l_prop_pc_s   hist_abt  i.fips*i.year i.fips*i.age i.age*i.year [aw=censwt] ,  weights rhotype(regress) cluster(fips);
 scalar rhohat = e(rho);
                                                                      
local myvars l_prop_pc_s hist_abt fy* fa* ay*;
unab myvars2 : `myvars';
                                                                      
***********************************************************
* Do the straightforward case as a check (no bias adjustment -- RHOHAT taken from PRAIS above);

* Do some checks ;
tsset;
disp rhohat;

foreach x of local myvars2 {;
   quietly             gen double       d`x'   = `x' - (rhohat)*L.`x';
   quietly by fipsage:          replace d`x'   = sqrt(1-rhohat^2)*`x' if _n == 1 | (_n > 1 & L.l_prop_pc_s == .);
};

list fips age year fipsage l_prop_pc_s dl_prop_pc_s in 1/50;

xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , robust;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsage) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(yobstate) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsyear) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fips) ;

drop dl_* dhist* dfy* dfa* day*;

*********************************************************************
* Do the back-of-the-envelope bias adjustment (informed by Solon 1984);
                                                                         
* do some checks and apply bias adjustment ;
tsset;
scalar newrhohat = .73;  * Roughly corresponds to an estimated rhohat of .5890 when T = 15;
disp rhohat;
disp newrhohat; 
scalar drop rhohat;

foreach x of local myvars2 {;
   quietly             gen double       d`x'   = `x' - (newrhohat)*L.`x';
   quietly by fipsage:          replace d`x'   = sqrt(1-newrhohat^2)*`x' if _n == 1 | (_n > 1 & L.l_prop_pc_s == .);
};

list fips age year fipsage l_prop_pc_s dl_prop_pc_s in 1/50;

xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , robust ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsage) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(yobstate) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsyear) ;
xi: reg    dl_prop_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fips) ;

drop dl_* dhist* dfy* dfa* day*;
scalar drop newrhohat;

/* *************************************************** */
/* *************************************************** */
/* Violent Crime ************************************ */ 

* SYA regression with varying population weights POPUL (as in TABLE I);                                                   
xi: reg  l_viol_pc_s hist_abt   i.fips*i.year i.fips*i.age i.age*i.year [aw=popul]  , cluster(fips);

* SYA regression with constant population weights CENSWT (needed for PRAIS);
xi: reg  l_viol_pc_s hist_abt   i.fips*i.year i.fips*i.age i.age*i.year [aw=censwt] , cluster(fips);
xi: reg  l_viol_pc_s hist_abt     fy*           fa*          ay*        [aw=censwt] , cluster(fips);

* PRAIS regression as STATA does it, no adjustment on RHOHAT;
xi: prais  l_viol_pc_s   hist_abt  i.fips*i.year i.fips*i.age i.age*i.year [aw=censwt] ,  weights rhotype(regress) cluster(fips);
 scalar rhohat = e(rho);
                                                                      
local myvars l_viol_pc_s hist_abt fy* fa* ay*;
unab myvars2 : `myvars';
                                                                      
***********************************************************
* Do the straightforward case as a check (no bias adjustment -- RHOHAT taken from PRAIS above);

* Do some checks ;
tsset;
disp rhohat;

foreach x of local myvars2 {;
   quietly             gen double       d`x'   = `x' - (rhohat)*L.`x';
   quietly by fipsage:          replace d`x'   = sqrt(1-rhohat^2)*`x' if _n == 1 | (_n > 1 & L.l_viol_pc_s == .);
};

list fips age year fipsage l_viol_pc_s dl_viol_pc_s in 1/50;

xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , robust;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsage) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(yobstate) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsyear) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fips) ;

drop dl_* dhist* dfy* dfa* day*;

*********************************************************************
* Do the back-of-the-envelope bias adjustment (informed by Solon 1984);
                                                                         
* do some checks and apply bias adjustment ;
tsset;
scalar newrhohat = .45;  * Roughly corresponds to an estimated rhohat of .3236 when T = 15;
disp rhohat;
disp newrhohat; 
scalar drop rhohat;

foreach x of local myvars2 {;
   quietly             gen double       d`x'   = `x' - (newrhohat)*L.`x';
   quietly by fipsage:          replace d`x'   = sqrt(1-newrhohat^2)*`x' if _n == 1 | (_n > 1 & L.l_viol_pc_s == .);
};

list fips age year fipsage l_viol_pc_s dl_viol_pc_s in 1/50;

xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , robust ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsage) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(yobstate) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fipsyear) ;
xi: reg    dl_viol_pc_s   dhist_abt     dfy*    dfa*    day* [aw=censwt] , cluster(fips) ;

drop dl_* dhist* dfy* dfa* day*;
scalar drop newrhohat;

exit, clear;
