/* ****************************************** */
/* YRAGE.DO                                   */
/*                                            */
/* Year-age regressions                       */
/*                                            */
/* ****************************************** */

#delimit ;
clear ;
set memory 100m;
set matsize 8000;

/* Get per-capita abortion and crime rates by */
/* collapsing the state-year-age data         */

use ~/.ifs4/fg_mar07/data/adata;
summ;

keep if age  >= 15   & age <= 24;
keep if year >= 1985 & year <= 2003;

list fips year seerpop if fips == 1 & age == 15;

gen prop_pc_s = 100000*(proparr/seerpop);
gen viol_pc_s = 100000*(violarr/seerpop);

tab fips if prop_pc_s ~= .;
tab year if prop_pc_s ~= .;

tab fips if viol_pc_s ~= .;
tab year if viol_pc_s ~= .;

sort year age;

collapse (mean) prop_pc_s viol_pc_s [fw=seerpop], by(year age);

gen l_prop_pc_s = ln(prop_pc_s);
gen l_viol_pc_s = ln(viol_pc_s);

sort year age;
save temp, replace;

/* Get age-specific total population by summing SEERPOP */

clear;
use ~/.ifs4/fg_mar07/data/adata;

keep if age  >= 15   & age <= 24;
keep if year >= 1985 & year <= 2003;

collapse (sum) seerpop, by(year age);

sort year age;
merge year age using temp;
tab _merge;
drop _merge;

sort year age;
save temp, replace;

/* Get age-specific total arrests from various issues of    */
/* "Crime in the United States." Turn into per-capita rates */ 
/* by dividing through by population totals obtained above  */

clear;
insheet using rawdata/cius.raw;
summ;

sort year age;
merge year age using temp;
tab _merge;
drop _merge;

gen violcius = 100000*(totviol/seerpop);
gen propcius = 100000*(totprop/seerpop);

gen l_violcius = ln(violcius);
gen l_propcius = ln(propcius);

sort year age;
save temp, replace;
clear;

/* Get per-capita rates from "Age-Specific and Race-Specific" publication */ 

insheet using rawdata/rates.raw;
sort year age;

merge year age using temp;
tab _merge;
drop _merge;

rename prate proppcr;
rename vrate violpcr;

gen l_violpcr = ln(violpcr);
gen l_proppcr = ln(proppcr);

sort year age;
save temp, replace;
clear;

/* Get abortion rates the preferred way,          */
/* by taking weighted means using t-a populations */
/* of states                                      */

use ~/.ifs4/fg_mar07/data/dlab_fg06;

keep fips year abresrt censpop;

replace censpop = round(censpop*1000,1);
replace year = year + 1900;
keep if year >= 1965 & year <= 2003;

list if fips <= 3;
tab fips;
tab year;
summ;

sort year fips;
collapse (mean) abresmean = abresrt [fw=censpop], by(year);

list;

foreach x of numlist 15/24 { ;
  gen abmean`x' =  (18/144)*abresmean[_n-((`x'+2))]/100 + 
                  (108/144)*abresmean[_n-((`x'+1))]/100 + 
                   (18/144)*abresmean[_n-((`x'  ))]/100; 

  replace abmean`x' = 0 if abmean`x' == .;
}; 

drop abresmean;
keep if year >= 1985 & year <= 2003;
list;

sort year;

reshape long abmean , i(year) j(age);

sort year age;
merge year age using temp;

tab _merge;
drop _merge;
erase temp.dta;

/* Write birth year (BYEAR) for clustering, tsset, and save dataset */

gen byear = year - age;

sort age year;
tsset age year;


save yrage, replace;

summ;
summ if year >= 1993 & year <= 2001;

tab year;
tab age;

/* **************************************************** */
/* Property Crime                                       */

xi: prais l_propcius  abmean i.age i.year, cluster(byear);
xi: prais l_prop_pc_s abmean i.age i.year, cluster(byear);

xi: prais l_propcius  abmean i.age i.year if year >= 1993, cluster(byear);
xi: prais l_prop_pc_s abmean i.age i.year if year >= 1993, cluster(byear);

* * * ;

xi: prais l_propcius  abmean i.age i.year if year <= 2001, cluster(byear);
xi: prais l_prop_pc_s abmean i.age i.year if year <= 2001, cluster(byear);

xi: prais l_propcius  abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);
xi: prais l_prop_pc_s abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);
xi: prais l_proppcr   abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);

/* **************************************************** */
/* Violent Crime                                       */

xi: prais l_violcius  abmean i.age i.year, cluster(byear);
xi: prais l_viol_pc_s abmean i.age i.year, cluster(byear);

xi: prais l_violcius  abmean i.age i.year if year >= 1993, cluster(byear);
xi: prais l_viol_pc_s abmean i.age i.year if year >= 1993, cluster(byear);

* * * ;

xi: prais l_violcius  abmean i.age i.year if year <= 2001, cluster(byear);
xi: prais l_viol_pc_s abmean i.age i.year if year <= 2001, cluster(byear);

xi: prais l_violcius  abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);
xi: prais l_viol_pc_s abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);
xi: prais l_violpcr   abmean i.age i.year if year >= 1993 & year <= 2001, cluster(byear);

* * * ;

exit, clear;
